@@ -326,6 +326,8 @@ function gen_self_cert() {
       if [[ ${CLOUDPLATFORM} == "GCP" ]]; then
 	#gke_tvaas-poc_us-west2_cms-cluster-casey
         kubectl config view --raw -o yaml|yq e ".clusters[]|select(.name==\"gke_${GCP_PROJECT}_${GCP_REGION}_${_clustername}\")" -| yq '.cluster.certificate-authority-data' - > $ca_folder/ca.crt
+      elif [[ ${CLOUDPLATFORM} == "AWS" ]]; then  
+        kubectl config view --raw -o yaml|yq e ".clusters[]|select(.name==\"$AWS_EKS_ARN\")" -| yq '.cluster.certificate-authority-data' - > $ca_folder/ca.crt
       else
         kubectl config view --raw -o yaml|yq e ".clusters[]|select(.name==\"$_clustername\")" -| yq '.cluster.certificate-authority-data' - > $ca_folder/ca.crt
       fi
@@ -392,18 +394,20 @@ function gen_self_cert() {
       sleep 3
       timeout 10 kubectl certificate approve ${_commonname}-${_namespace}-csr
       sleep 3
-      while [[ -z "$(cat $ca_folder/tls.crt 2>/dev/null)" ]] || grep -q "null" $ca_folder/tls.crt;do
-        #timeout 10 kubectl get csr ${_commonname}-${_namespace}-csr -o yaml|yq r - 'status.certificate' > $ca_folder/tls.crt
-        timeout 10 kubectl get csr ${_commonname}-${_namespace}-csr -o yaml|yq '.status.certificate' - > $ca_folder/tls.crt
-        sleep 1
-      done
+      #while [[ -z "$(cat $ca_folder/tls.crt 2>/dev/null)" ]] || grep -q "null" $ca_folder/tls.crt;do
+      #  #timeout 10 kubectl get csr ${_commonname}-${_namespace}-csr -o yaml|yq r - 'status.certificate' > $ca_folder/tls.crt
+      #  timeout 10 kubectl get csr ${_commonname}-${_namespace}-csr -o yaml|yq '.status.certificate' - > $ca_folder/tls.crt
+      #  
+      #  sleep 1
+      #done
 
       echo "[INFO] Get tls.crt for ${_commonname}"
+      openssl x509 -req -in /tmp/cms_ca/req.csr -signkey /tmp/cms_ca/tls.key -out /tmp/cms_ca/tls.crt -days 3650
       #cat $ca_folder/tls.crt
       #echo "[INFO] ------------------------------------------------"
 
-      export SELF_CA_CRT=$(cat $ca_folder/ca.crt)
-      export SELF_TLS_CRT=$(cat $ca_folder/tls.crt)
+      export SELF_CA_CRT=$(cat $ca_folder/ca.crt|base64 -w 0)
+      export SELF_TLS_CRT=$(cat $ca_folder/tls.crt|base64 -w 0)
       export SELF_TLS_KEY=$(cat $ca_folder/tls.key|base64 -w 0)
 
     #==================================================
